@@ -9,8 +9,8 @@ pub struct Dim4 {
 
 /// Default trait for Dim4 returns an Array of dimensions [1, 1, 1, 1]
 impl Default for Dim4 {
-    fn default() -> Dim4 {
-        Dim4 { dims:[1, 1, 1, 1] }
+    fn default() -> Self {
+        Self { dims: [1, 1, 1, 1] }
     }
 }
 
@@ -30,7 +30,7 @@ impl Default for Dim4 {
 impl Index<usize> for Dim4 {
     type Output = u64;
 
-    fn index<'a>(&'a self, _index: usize) ->&'a u64 {
+    fn index<'a>(&'a self, _index: usize) -> &'a u64 {
         &self.dims[_index]
     }
 }
@@ -47,7 +47,11 @@ impl Index<usize> for Dim4 {
 /// ```
 impl fmt::Display for Dim4 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "[{} {} {} {}]", self.dims[0], self.dims[1], self.dims[2], self.dims[3])
+        write!(
+            f,
+            "[{} {} {} {}]",
+            self.dims[0], self.dims[1], self.dims[2], self.dims[3]
+        )
     }
 }
 
@@ -60,13 +64,13 @@ impl Dim4 {
     /// use arrayfire::Dim4;
     /// let dims = Dim4::new(&[4, 4, 2, 1]);
     /// ```
-    pub fn new(dims: &[u64; 4]) -> Dim4 {
-        Dim4 { dims: dims.clone(), }
+    pub fn new(dims: &[u64; 4]) -> Self {
+        Self { dims: dims.clone() }
     }
 
     /// Get the number of elements represented by Dim4 object
     pub fn elements(&self) -> u64 {
-        self.dims[0]*self.dims[1]*self.dims[2]*self.dims[3]
+        self.dims[0] * self.dims[1] * self.dims[2] * self.dims[3]
     }
 
     /// Get the number of dimensions of Dim4
@@ -76,11 +80,16 @@ impl Dim4 {
             0 => 0,
             1 => 1,
             _ => {
-                if self.dims[3] != 1 { 4 }
-                else if self.dims[2] != 1 { 3 }
-                else if self.dims[1] != 1 { 2 }
-                else { 1 }
-            },
+                if self.dims[3] != 1 {
+                    4
+                } else if self.dims[2] != 1 {
+                    3
+                } else if self.dims[1] != 1 {
+                    2
+                } else {
+                    1
+                }
+            }
         }
     }
 
